AclInfo

Struct AclInfo 

pub struct AclInfo {
    pub flags: Vec<Rule>,
    pub passwords: Vec<Rule>,
    pub commands: Vec<Rule>,
    pub keys: Vec<Rule>,
    pub channels: Vec<Rule>,
    pub selectors: Vec<Rule>,
}
An info dictionary type storing Redis ACL information as multiple Rule. This type collects key/value data returned by the ACL GETUSER command.

Fields

flags: Vec<Rule>

Describes flag rules for the user. Represented by Rule::On, Rule::Off, Rule::AllKeys, Rule::AllCommands and Rule::NoPass.

passwords: Vec<Rule>

Describes the user’s passwords. Represented by Rule::AddHashedPass.

commands: Vec<Rule>

Describes capabilities of which commands the user can call. Represented by Rule::AddCommand, Rule::AddCategory, Rule::RemoveCommand and Rule::RemoveCategory.

keys: Vec<Rule>

Describes patterns of keys which the user can access. Represented by Rule::Pattern.

channels: Vec<Rule>

Describes pub/sub channel patterns. Represented by Rule::Channel.

selectors: Vec<Rule>

Describes selectors. Represented by Rule::Selector.